#ifndef QSPLAT_GUI_WXVIEWER_H
#define QSPLAT_GUI_WXVIEWER_H

/*
 port by Jonathan Berger
 Szymon Rusinkiewicz

 qsplat_gui_wxviewer.h
 MainFrame and GLCanvas

 Copyright (c) 1999-2000 The Board of Trustees of the
 Leland Stanford Junior University.  All Rights Reserved.
 */

#include "wx/wx.h"
#include "wx/glcanvas.h"

class GLCanvas;
class MainFrame: public wxFrame
{
public:
    GLCanvas	*m_canvas;
    wxTimer	*m_timer;
    wxSlider	*m_frame_slider;
    wxStaticText *m_frame_text;
    bool	blit_active;
    
    MainFrame(wxFrame *frame, const wxString& title, const wxPoint& pos,
              const wxSize& size, long style = wxDEFAULT_FRAME_STYLE);

    // Callback methods
    void OnMenu(wxCommandEvent& event);
    void OnChar(wxKeyEvent& event);
    void OnTimer(wxTimerEvent& event);
    void OnClose(wxCloseEvent& WXUNUSED(event));
    void OnSliderUpdate(wxScrollEvent &event);
    void someOtherName(wxActivateEvent& event);

    // Other methods
    void Open();
    void Exit();
    void getCanvasDimensions(int &width, int &height);
    void SetSlider(float val);
    void DisplayDialog(const char *title, const char *message);
    
private:
    void initMenuBar();
    void initStatusBar();
    void setSliderLabel(float val);
    DECLARE_EVENT_TABLE()
};


class GLCanvas: public wxGLCanvas
{
public:
    GLCanvas::GLCanvas(wxWindow *parent, const wxWindowID id = -1,
                   const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize,
                       long style = 0, const wxString& name = "GLCanvas") :
        wxGLCanvas(parent, (wxGLCanvas*) NULL, id, pos, size, style, name )
    { m_init = FALSE; }
    
    // Callback methods
    void OnPaint(wxPaintEvent& event);
    void OnSize(wxSizeEvent& event);
    void OnEraseBackground(wxEraseEvent& event);
    void OnEnterWindow( wxMouseEvent& event );
    void OnMouseEvent(wxMouseEvent& event);
    void OnChar(wxKeyEvent& event);

private:
    bool m_init;
    DECLARE_EVENT_TABLE()
};


enum wxID {
    //File menu
    ID_OPEN = 10000,

    //Options menu
    ID_SHINY,
    ID_BACKFACE_CULL,
    ID_SHOW_LIGHT,
    ID_SHOW_REFINEMENT,
    ID_AUTO_SPIN,

    //Commands menu
    ID_GO_FULLSCREEN,
    ID_RESET_VIEWER,
    ID_SET_FRAMERATE,

    //Help menu
    ID_ABOUT_QSPLAT,
    ID_ABOUT_THIS_MODEL,

    //Driver menu
    ID_OPENGL_SUB,
    ID_SOFTWARE_SUB,
    ID_VISUALIZATIONS_SUB,

    //other IDs
    ID_FRAME_SLIDER,
    ID_FRAME_TEXT,
    ID_TIMER
};


#endif
